<?php 

	define('IsMobile', wp_is_mobile());
	define('TPLDIR', get_template_directory_uri());

add_action( 'after_setup_theme', 'olo_setup' );
function olo_setup(){
	// for /languages/
	load_theme_textdomain( 'olo', get_template_directory().'/languages' );

	//set content width for video
	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 600;

	//wp_title
	add_theme_support( 'title-tag' );
	add_filter( 'document_title_separator', 'hjyl_title_separator_to_line' );
	add_filter( 'document_title_parts', 'hjyl_document_title_parts' );
	
	//Add background for theme
	add_theme_support('custom-background');
	
	add_theme_support( "responsive-embeds" );
	
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		)
	);
	//post-thumbnails
	add_theme_support( 'post-thumbnails' );
	add_image_size('index', 160, 90);
	
	//editor style
	add_editor_style('css/editor.css');

	register_block_style(
	    'core/quote',
	    array(
	        'name'         => 'blue-quote',
	        'label'        => __( 'Blue Quote', 'olo' ),
	        'inline_style' => '.wp-block-quote.is-style-blue-quote { color: blue; }',
	    )
	);
	register_block_pattern(
	    'olo/my-awesome-pattern',
	    array(
	        'title'       => __( 'Two buttons', 'olo' ),
	        'description' => _x( 'Two horizontal buttons, the left button is filled in, and the right button is outlined.', 'Block pattern description', 'olo' ),
	        'content'     => "<!-- wp:buttons {\"align\":\"center\"} -->\n<div class=\"wp-block-buttons aligncenter\"><!-- wp:button {\"backgroundColor\":\"very-dark-gray\",\"borderRadius\":0} -->\n<div class=\"wp-block-button\"><a class=\"wp-block-button__link has-background has-very-dark-gray-background-color no-border-radius\">" . esc_html__( 'Button One', 'olo' ) . "</a></div>\n<!-- /wp:button -->\n\n<!-- wp:button {\"textColor\":\"very-dark-gray\",\"borderRadius\":0,\"className\":\"is-style-outline\"} -->\n<div class=\"wp-block-button is-style-outline\"><a class=\"wp-block-button__link has-text-color has-very-dark-gray-color no-border-radius\">" . esc_html__( 'Button Two', 'olo' ) . "</a></div>\n<!-- /wp:button --></div>\n<!-- /wp:buttons -->",
	    )
	);
	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );
	
	add_theme_support( 'align-wide' );
	
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	//olo Title Tag
	add_theme_support( "title-tag" );
	
	// Enqueue style-file, if it exists.
	add_action('wp_enqueue_scripts', 'olo_script');
	
	//copyright below single
	add_filter('the_content', 'olo_copyright');
	
	// add @ for comment
	add_filter( 'comment_text' , 'hjyl_comment_add_at', 20, 2);
	
	// Add sidebar
	add_action( 'widgets_init', 'olo_widgets' );
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
		$args = array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		);
	add_theme_support( "html5", $args );

	//Add support for core custom logo.
		$args = array(
			'height'			=> 100,
			'width'				=> 100,
			'flex-width'		=> true,
			'flex-height'		=> true,
			'header-text'		=> array( 'site-title', 'site-description' ),
		);
	add_theme_support( "custom-logo", $args );
	add_theme_support( "custom-header" );
	// Add menu
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'olo'),
		'mobile' => __( 'Mobile Navigation', 'olo'),
	) );
};

//change the_title "-" to "|"
function hjyl_title_separator_to_line(){
        return '|';
}
function hjyl_document_title_parts( $title ){
    if( is_home() && isset( $title['tagline'] ) ) unset( $title['tagline'] );
	//no title
	if(is_singular() && ""==get_the_title() ) { 
		$title['title'] = sprintf(__('Untitled #%s', 'olo'),get_the_date('Y-m-d'));
	};
    return $title;
}

//Custom wp_list_pages
function olo_wp_list_pages(){
	echo "<ul>";
	echo wp_list_pages('title_li=&depth=1');
	echo "</ul>";
}

// Enqueue style-file, if it exists.
function olo_script() {
	if( !IsMobile ){
		wp_enqueue_style( 'olo', get_stylesheet_uri(),  array(), '20220106', false);
	}else{
		wp_enqueue_style('mobile', TPLDIR . '/css/mobile.css', array(), '20220106', false);
	};
	wp_enqueue_style( 'Play', '//fonts.googleapis.com/css?family=Play', array(), '20220106', 'all');
	wp_enqueue_script( 'olo', TPLDIR . '/js/olo.js', array('jquery'), '20220106', true);
	if ( is_singular() && comments_open() ) {
	wp_enqueue_script( 'comment-reply' );
	wp_enqueue_script( 'ajax-comment', TPLDIR . '/js/comments-ajax.js', array('jquery'), '20220106', true);
	}
	wp_localize_script( 'ajax-comment', 'ajaxcomment', array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'order' => get_option('comment_order'),
		'formpostion' => 'bottom',
		'txt1' => __('Wait a moment...', 'olo'),
		'txt2' => __('Good Comment', 'olo'),
	) );	
	if( is_page('archives') ){
		wp_enqueue_script( 'archives', TPLDIR . '/js/archives.js', array(), '20220106', false);
		wp_enqueue_style( 'archives', TPLDIR . '/css/archives.css', array(), '20220106', 'screen');
	};
	if(is_404()){
		wp_enqueue_style( '4041', 'http://fonts.googleapis.com/css?family=Press+Start+2P', array(), '20220106', 'screen');
		wp_enqueue_style( '4042', 'http://fonts.googleapis.com/css?family=Oxygen:700', array(), '20220106', 'screen');
		wp_enqueue_style( '4043', TPLDIR . '/css/404.css', array(), '20220106', 'screen');
	}
}

//copyright below single
function olo_copyright($content) {
  if (is_singular() || is_feed()) {
    $content .=
      '<div id="content-copyright"><span style="font-weight:bold;text-shadow:0 1px 0 #ddd;font-size: 13px;">'.
	  __('CopyRights: ','olo').
	  '</span><span style="font-size: 13px;">'.
	  __('The Post by ','olo').
	  '<a rel="nofollow" href="https://creativecommons.org/licenses/by-nc-sa/3.0/" title="'.
	  __('CC BY-NC-SA 3.0','olo').
	  '">BY-NC-SA</a> '.
	  __('For Authorization，Original If Not Noted，Reprint Please Indicate From ','olo').
	  '<a href="' .
      home_url() .
      '">' .
      get_bloginfo('name') .
      '</a><br>'.
	  __('Post Link: ','olo').
	  '<a rel="bookmark" title="' .
      get_the_title() .
      '" href="' .
      get_permalink() .
      '">' .
      get_the_title() .
      '</a></span></div>';
  }
	return $content;
}
// add @ for comment
function hjyl_comment_add_at( $comment_text, $comment = '') {
  if( $comment->comment_parent > 0) {
    $comment_text = '@<a href="#comment-' . $comment->comment_parent . '">'.get_comment_author( $comment->comment_parent ) . '</a> ' . $comment_text;
  }

  return $comment_text;
}
//time formats "xxxx ago"
function timeago($ptime) {
    $ptime = strtotime($ptime);
    $etime = time() - $ptime;
    if ($etime < 1) return __('Just Now','olo');
    $interval = array(
        12 * 30 * 24 * 60 * 60 => __('years ago', 'olo'),
        30 * 24 * 60 * 60 => __('month ago', 'olo'),
        7 * 24 * 60 * 60 => __('weeks ago', 'olo'),
        24 * 60 * 60 => __('days ago', 'olo'),
        60 * 60 => __('hours ago', 'olo'),
        60 => __('minutes ago', 'olo'),
        1 => __('seconds ago', 'olo')
    );
    foreach ($interval as $secs => $str) {
        $d = $etime / $secs;
        if ($d >= 1) {
            $r = round($d);
            return $r . $str;
        }
    };
}

// Add sidebar
function olo_widgets(){
    register_sidebar(array(
		'name' =>''.__('Home', 'olo').'',
		'id' => 'home',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h2><span class="star">',
        'after_title' => '</span></h2>',
    ));
    register_sidebar(array(
		'name'=>''.__('Single', 'olo').'',
		'id' => 'single',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h2><span class="star">',
        'after_title' => '</span></h2>',
    ));
	register_sidebar(array(
		'name'=>''.__('Other', 'olo').'',
		'id' => 'other',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h2><span class="star">',
        'after_title' => '</span></h2>',
    ));
}

//move comment field to bottom
function move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'move_comment_field_to_bottom' );
//Load Custom parts
require( get_template_directory() . '/inc/theme_inc.php' );
require( get_template_directory() . '/inc/oloComment.php' );
 $olo_theme_options = get_option('olo_theme_options');

/**
 * @TwnetySeventeen
 * Get unique ID.
 */
function hjyl_unique_id( $prefix = '' ) {
	static $id_counter = 0;
	if ( function_exists( 'wp_unique_id' ) ) {
		return wp_unique_id( $prefix );
	}
	return $prefix . (string) ++$id_counter;
}

/**
 * Add SVG definitions to the footer.
 */
function hjyl_include_svg_icons() {
	// Define SVG sprite file.
	$svg_icons = get_parent_theme_file_path( '/images/svg-icons.svg' );

	// If it exists, include it.
	if ( file_exists( $svg_icons ) ) {
		require_once( $svg_icons );
	}
}
add_action( 'wp_footer', 'hjyl_include_svg_icons', 9999 );

/**
 * Return SVG markup.
 *
 */
function hjyl_get_svg( $args = array() ) {
	// Make sure $args are an array.
	if ( empty( $args ) ) {
		return __( 'Please define default parameters in the form of an array.', 'olo' );
	}

	// Define an icon.
	if ( false === array_key_exists( 'icon', $args ) ) {
		return __( 'Please define an SVG icon filename.', 'olo' );
	}

	// Set defaults.
	$defaults = array(
		'icon'     => '',
		'title'    => '',
		'desc'     => '',
		'fallback' => false,
	);

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Set aria hidden.
	$aria_hidden = ' aria-hidden="true"';

	// Set ARIA.
	$aria_labelledby = '';

	/*
	 * Twenty Seventeen doesn't use the SVG title or description attributes; non-decorative icons are described with .screen-reader-text.
	 *
	 * However, child themes can use the title and description to add information to non-decorative SVG icons to improve accessibility.
	 *
	 * Example 1 with title: <?php echo hjyl_get_svg( array( 'icon' => 'arrow-right', 'title' => __( 'This is the title', 'textdomain' ) ) ); ?>
	 *
	 * Example 2 with title and description: <?php echo hjyl_get_svg( array( 'icon' => 'arrow-right', 'title' => __( 'This is the title', 'textdomain' ), 'desc' => __( 'This is the description', 'textdomain' ) ) ); ?>
	 *
	 * See https://www.paciellogroup.com/blog/2013/12/using-aria-enhance-svg-accessibility/.
	 */
	if ( $args['title'] ) {
		$aria_hidden     = '';
		$unique_id       = hjyl_unique_id();
		$aria_labelledby = ' aria-labelledby="title-' . $unique_id . '"';

		if ( $args['desc'] ) {
			$aria_labelledby = ' aria-labelledby="title-' . $unique_id . ' desc-' . $unique_id . '"';
		}
	}

	// Begin SVG markup.
	$svg = '<svg class="icon icon-' . esc_attr( $args['icon'] ) . '"' . $aria_hidden . $aria_labelledby . ' role="img">';

	// Display the title.
	if ( $args['title'] ) {
		$svg .= '<title id="title-' . $unique_id . '">' . esc_html( $args['title'] ) . '</title>';

		// Display the desc only if the title is already set.
		if ( $args['desc'] ) {
			$svg .= '<desc id="desc-' . $unique_id . '">' . esc_html( $args['desc'] ) . '</desc>';
		}
	}

	/*
	 * Display the icon.
	 *
	 * The whitespace around `<use>` is intentional - it is a work around to a keyboard navigation bug in Safari 10.
	 *
	 * See https://core.trac.wordpress.org/ticket/38387.
	 */
	$svg .= ' <use href="#icon-' . esc_html( $args['icon'] ) . '" xlink:href="#icon-' . esc_html( $args['icon'] ) . '"></use> ';

	// Add some markup to use as a fallback for browsers that do not support SVGs.
	if ( $args['fallback'] ) {
		$svg .= '<span class="svg-fallback icon-' . esc_attr( $args['icon'] ) . '"></span>';
	}

	$svg .= '</svg>';

	return $svg;
}
